\name{likfit}

\alias{likfit}
\alias{proflik.phi}
\alias{proflik.ftau}
\alias{proflik.nug}
\alias{loglik.spatial}
\alias{likfit.nospatial}

%- Also NEED an `\alias' for EACH other topic documented here.

\title{Likelihood estimation for the parameters of a (transformed) Gaussian random field}

\description{
  This function estimates parameters of a (transformed) Gaussian random field using
  either \emph{maximum likelihood} (ML) or \emph{restricted maximum
    likelihood} (REML).
  Includes option for the estimation the Box-Cox transformation parameter.
}

\usage{
likfit(geodata, coords=geodata$coords, data=geodata$data, trend = "cte",
       ini, fix.nugget = FALSE, nugget = 0, 
       cov.model = c("matern", "exponential", "gaussian", "spherical",
         "circular", "cubic", "wave", "powered.exponential",
         "cauchy", "gneiting", "gneiting.matern", "pure.nugget"),
       kappa = 0.5, fix.lambda = TRUE, lambda = 1, method = "ML", 
       predicted = FALSE, residuals = FALSE, 
       minimisation.function = c("optim","nlmP", "nlm"),
       automatic.refit = FALSE, range.limits, messages.screen = TRUE, ...) 
}

%- maybe also `usage' for other objects documented here.

\arguments{
  \item{geodata}{a list containing elements \code{coords} and
    \code{$data} described below. If not provided the arguments
    \code{coords} and \code{data} must be provided instead.}
  \item{coords}{ a \emph{nx2} matrix containing in each row Euclidean
    coordinates of the \emph{n} data locations. By default it takes the
    element \code{$coords} of the argument \code{geodata}.}
  \item{data}{a vector with data values. By default it takes the
    element \code{$data} of the argument \code{geodata}.}
  \item{trend}{specifies the mean part of the model. The options are:
    \code{"cte"} (constant mean - default option), \code{"1st"} (a first degree polynomial
    on the coordinates), \code{"2nd"} (a second degree polynomial
    on the coordinates), or a formula of the type \code{~X} where \code{X}
    is a matrix with the covariates (external trend). }
  \item{ini}{initial values of the covariance parameters. These values
    are used to initiate the numerical minimizer. If the model to be
    fitted has 3 parameters: nugget (\eqn{\tau^2}{tau^2}), sill (\eqn{\sigma^2}{sigma^2})
    and range (\eqn{\phi}{phi}), \code{ini} is a vector with initial values for
    these tree parameters. If the model to be fitted does not have has
    nugget \code{ini} is a vector with 2 components, the initial values for
    \eqn{\sigma^2}{sigma^2} and \eqn{\phi}{phi}. If \code{ini} is a matrix with several
    initial values on the rows a search for the better initial value is
    performed. The values of the likelihood function is computed for each of
    them and the row with maximum value is used to initiate the numerical maximization.}
  \item{fix.nugget}{A flag indication whether or not the nugget parameter
    must be included in the estimation. If \code{fix.nugget = T} the
    argument \code{ini} must be a vector of length 2 or a matrix with 2 columns}
  \item{nugget}{Value of the nugget parameter when \code{fix.nugget = TRUE}. Defaults to zero.}
  \item{cov.model}{model for the correlation function. See options in the
    function call and/or documentation for the function \code{\link{cov.spatial}}. }
  \item{kappa}{extra parameter needed for some of the correlation
    functions: (\code{"matern", "powered.exponential", "gneiting"} and
    \code{"gneiting.matern"}). For more details see documentation for the
    function \code{\link{cov.spatial}}. This parameter is always regarded
    as fixed during the ML/REML parameter estimation.}
  \item{fix.lambda}{If \code{TRUE} (default option) the transformation parameter is regarded as fixed (known) during the estimation process otherwise the ML/REML for this parameter is also computed.}
  \item{lambda}{Box-Cox transformation parameter. Two particular cases are \code{lambda = 1} which corresponds to no
    transformation and \code{lambda=0} corresponding to the log-transformation.    The value of the transformation parameter \eqn{\lambda}{lambda} is regarded as a fixed value for the parameter if \code{fix.lambda = TRUE} or is used as a initial value in the search if  \code{fix.lambda = FALSE}.}
  \item{method}{\code{ML} for maximum likelihood or \code{REML} for restricted maximum likelihood.}
  \item{predicted}{predicted values at the data locations}
  \item{residuals}{residuals at the data locations}
  \item{automatic.refit}{Defaults to \code{FALSE}. If set to \code{TRUE} the model is automatically
    changed and fitted again as follows:
    \itemize{
      \item In the case of a model with nugget, if the relative nugget
      is less than 0.01 the model without nugget is fitted.
      \item If the range parameters is less than \eqn{1e-12} or a value
      provided in the argument \code{range.limits} a model without
      spatial correlation is fitted.
      }
  }
  \item{minimisation.func}{minimisation function to be used}
  \item{range.limits}{minimum and maximum values allowed for the
    correlation function parameter (range). Defaults to  \code{c(0, +Inf)}.}
  \item{messages.screen}{a flag \code{TRUE} or \code{FALSE} indicating
    whether or not messages are printed on the screen (or output device)
    while the function is running.}
  \item{\dots}{additional parameters to be passed to the minimization
    function. Typically \code{control} type arguments which controls the
    behavior of the minimization algorithm. See documentation of
    the minimization functions for further details.}
}

%\details{
% ~~ If necessary, more details than the __description__  above ~~
%}

\value{
  A list with the following components:
  \item{cov.model}{a string with the name of the correlation
    function. See function call for the options.}
  \item{nugget}{value of the nugget parameter \eqn{\tau^2}{tau^2}. This
    is the estimated value if \code{fix.nugget = FALSE} or the fixed
    (known) value if \code{fix.nugget = TRUE}.}
  \item{cov.pars}{a 2 elements vector with the estimated sill and range
    parameters, respectively.}
  \item{kappa}{(fixed) value of the smoothness parameter required by
    some of the correlation functions.}
  \item{beta}{estimated mean parameters. Can be either a scalar or
    vector depending on the trend model (covariates) used.}
  \item{beta.var}{variance (or covariance matrix) of the mean parameter. }
  \item{lambda}{Box-Cox transformation parameter. A fixed (know) value if
  \code{fix.lambda = TRUE} or the estimated value if \code{fix.lambda = FALSE}.}
  \item{loglik}{the value of the maximized likelihood.}
  \item{npars}{number of estimated parameters.}
  \item{AIC}{Value of the Akaike information criteria.}
  \item{BIC}{Value of the Bayesian information criteria.}
  \item{trend.ols}{Trend (mean parameters) estimated by ordinary least
    squares (i.e. ignoring the spatial correlation).}
  \item{info.lambda}{information about the Box-Cox transformation
    parameter to be used by other functions which uses the output of \code{likfit()}.}
  \item{method}{Estimation method used, \code{"ML"} (maximum likelihood)
    or \code{"REML"} (restricted maximum likelihood).}
  \item{s2}{estimated residual variance. Only returned if
    \code{predicted = TRUE} or \code{residuals = TRUE}.}
  \item{predicted}{predicted values at data locations. Only returned if
    \code{predicted = TRUE}.}
  \item{residuals}{estimated residuals at data locations. Only returned if
    \code{residuals = TRUE}.}
  \item{info}{results returned by the minimization function.}
  \item{max.dist}{maximum distance found between 2 data points. This
    information is used by other functions which uses results from \code{likfit()}.}
  \item{trend.matrix}{trend matrix (covariates).}
  \item{call}{the function call.}
}

\references{
  Further information about \code{geoR/geoS} can be found at:\cr
  \url{http://www.maths.lancs.ac.uk/~ribeiro/geoR.html}
}

\author{
  Paulo Justiniano Ribeiro Jr. <\email{paulojus@est.ufpr.br}> \cr
  Peter J. Diggle <\email{p.diggle@lancaster.ac.uk}>.
}

\note{\code{proflik.phi}, \code{proflik.ftau}, \code{proflik.nug} are
  auxiliary functions which computed the value of the likelihood for
  models without nugget, with a fixed nugget and including nugget,
  respectively.
  These functions are internally called by the minimization function when
  estimating the model parameters.
}

%~Make other sections like WARNING with \section{WARNING }{....} ~

\seealso{\code{\link{summary.variomodel}}, \code{\link{olsfit}},
  \code{\link{wlsfit}}, 
  \code{\link{plot.variogram}}, \code{\link{lines.variogram}},
  \code{\link{lines.variomodel}}, \code{\link{proflik}},
  \code{\link{optim}}, \code{\link{nlm}}
  }

\examples{
data(s100)
ml <- likfit(s100, ini=c(.5, .5), fix.nug=T)
summary(ml)
reml <- likfit(s100, ini=c(.5, .5), fix.nug=T, met="REML")
summary(reml)
plot(variog(s100))
lines(ml)
lines(reml, lty=2)


}

\keyword{spatial}
