\name{variog}

\alias{variog}
\alias{rfm.bin}
%- Also NEED an `\alias' for EACH other topic documented here.

\title{Computes empirical (sample) variogram}

\description{
  Computes sample variograms using either the \emph{classical} or \emph{robust}
  estimator. Output can be returned as a \code{binned variogram}, a \code{
    variogram cloud} or a \code{smoothed variogram}. Data
  transformation (Box-Cox) is allowed. Trends (fitted by ordinary least
  squares) can be removed and, in this case,  variogram for the residuals are computed.
}

\usage{
variog(geodata, coords=geodata$coords, data=geodata$data, lambda = 1, trend = "cte",
       option=c("bin", "cloud", "smooth"),
       estimator.type=c("classical", "robust"), uvec="default",
       nugget.tolerance=0, max.dist="all", pairs.min=NULL,
       bin.cloud=F, n.points=50, ...)
}
%- maybe also `usage' for other objects documented here.

\arguments{
  \item{geodata}{a list contanining elements \code{coords} and
    \code{$data} described below. If not provided the arguments
    \code{coords} and \code{data} must be provided instead.}
  \item{coords}{a \emph{nx2} matrix contanining
    coordinates of the \emph{n} data locations in each row.
    Defaults to \code{geodata$coords}, if provided.}
  \item{data}{a vector or matrix with data values.
    If a matrix is provided each colunm is regarded as one variable or realisation.
    Defaults to \code{geodata$data}, if provided.}
  \item{lambda}{Box-Cox transformation parameter. Defaults to 1 (no
    transformation) otherwise the variogram is computed for transformed
    data. Notice that \code{\lambda = 0} implies log-transformation.}
  \item{trend}{defines the mean part of the model (or trend).
    The default is \code{"cte"} implying constant mean. Other
    options are \code{"1st"} (trend is a first degree polinomial on the
    coordinates), \code{"2nd"} (trend is a second degree polinomial on the
    coordinates), or a formula of the type ~X where X is a matrix with
    external trend (covariates) measured at data locations.
    If trend is different from \code{"cte"}
    a linear model defined by the trend is fitted to the data and
    variogram are computed for the residuals.}
  \item{option}{defines the output type: \code{bin} returns values of
    binned variogram, \code{cloud} returns the variogram cloud and \code{
      smooth} returns the kernel smoothed variogram. Defaults to \code{"bin"}.}
  \item{estimator.type}{\code{classical} computes the classical method of
    moments estimator and \code{robust} returns the robust variogram
    estimator. See Cressie (1993) for the expressions of the estimators.
    Defaults to \code{"classical"}.}
  \item{uvec}{a vector with values defining the variogram binning when
    \code{option = "bin"}. The values of \code{uvec} defines the middle
    points of the bins.\cr
    If uvec[1] > 0 the first bin is: 0 < u <= uvec[2] - 0.5*(uvec[2] - uvec[1]).\cr
    If uvec[1] = 0 first bin is: 0 < u <= 0.5*uvec[1] and uvec[1] is
    replaced by the midpoint of this interval.}
  \item{nugget.tolerance}{a number defining a distance. Distances
    between pairs of points lower than this values are set to zero and
    the pairs are used to estimate the nugget effect. Defaults to zero.}
  \item{max.dist}{a number defining a distance. Pairs of points
    separated for distance greater than this value are ignored in the
    variogrm calculation. Defaults to the maximum distance
    between to points.}
  \item{pairs.min}{a integer number. If \code{option = "bin"}, bins with number of pairs smaller than this
    value are ignored. Defaults to {NULL}.}
  \item{bin.cloud}{Logical. If \code{TRUE} and \code{option = "bin"} the cloud values for each class are
    also included in the output. Defaults to \code{FALSE}.}
  \item{n.points}{an integer number. Specifies the number of points in
    the samle variogram if \code{option = "smooth"}. Defaults to 50.}
  \item{\dots}{passes arguments to the function \code{\link{ksmooth}}, if
    \code{option = "smooth"}.  }
}

\details{
  Variograms are widely used in geostatistical analysis for exploratory
  purposes, to estimate covariance parameters, or to compare theoretical
  and/or fitted models againt sample variograms.
  In this function, prior to the variogram computation, data can be transformed (Box-Cox) and/or
  trend can be removed (by ordinary least squares) if covariates
  are provided.  For the later, variograms are computed for the residuals.
}

\value{
  A list with components:
  \item{u }{a vector with distances.}
  \item{v }{a vector with estimated variogram values at distances \code{u}.}
  \item{n }{number of pairs in each bin if
    \code{option = "bin"}.  }
  \item{var.mark }{variance of the data.}
  \item{output.type }{echoes the \code{option} argument.  }
  \item{estimator.type }{echoes the estimator used.  }
  \item{n.data }{number of data points.  }
  \item{call }{the function call.  }
  
  The class \code{variogram} is assigned.
}

\references{
  Cressie, N.A.C.(1993) \emph{Statistics for Spatial Data}, Wiley.
  
  Further information about \code{geoR/geoS} can be found at:\cr
  \url{http://www.maths.lancs.ac.uk/~ribeiro/geoR.html}
}

\author{Paulo J. Ribeiro Jr. \email{<paulojus@est.ufpr.br>} \cr
  Peter J. Diggle \email{<p.diggle@lancaster.ac.uk>}.
}

\seealso{\code{\link{variog.env}}, \code{\link{olsfit}},
  \code{\link{wlsfit}}, \code{\link{plot.variogram}}.
}

\examples{
# generating simulated data:
vario.b <- variog(sim, max.dist=1)  

# computing variogram:
vario.b <- variog(sim, max.dist=1)                   # computes binned variogram 
vario.c <- variog(sim, max.dist=1, op="cloud")       # computes variogram cloud
vario.bc <- variog(sim, max.dist=1, bin.cloud=T)     # computes binned variogram and stores the cloud
vario.s <- variog(sim, max.dist=1, op="sm", band=0.2)# computes smooth
variogram

# plotting the variograms:
par(mfrow=c(2,2))
plot(vario.b, main="binned variogram") 
plot(vario.c, main="variogram cloud")
plot(vario.bc, bin.cloud=T, main="clouds for binned variogram")  
plot(vario.s, main="smoothed variogram") 

}

\keyword{spatial, smooth}










